@@ -196,7 +196,7 @@ class Client:
         if "gs://" in file_path:
             # GCS BUCKET
             if extension in self.text_file_list:
-                content = self.__read_gcs_blob(file_path).encode("UTF-8")
+                content = self.__read_gcs_blob(file_path)
                 return content.replace(b'\r\n', b'\n')
             else:
                 file_bytes = self.__read_gcs_blob(file_path)
@@ -226,10 +226,7 @@ class Client:
         bucket              = self.__google_storage_client.bucket(bucket_name)
         blob                = bucket.blob(source_blob_name)
 
-        if extension in self.text_file_list:
-            content = blob.download_as_text()
-        else:
-            content = blob.download_as_bytes()
+        content = blob.download_as_bytes()
 
         return content
 
@@ -244,5 +241,5 @@ class Client:
             blob.upload_from_string(contents)
             return True
         except Exception as e:
-            Helpers.print_error("Could not connect to GCS client " + str(e))
+            Helpers.print_error("Could not upload blob " + str(e))
             sys.exit(1)
\ No newline at end of file
